package com.hchyun.test.service;

import java.util.List;

import com.hchyun.common.utils.ServerResult;
import com.hchyun.test.entity.Results;

/**
 * 成绩Service接口
 * 
 * @author hchyun
 * @date 2021-01-24
 */
public interface ResultsService
{
    /**
     * 查询成绩
     * 
     * @param id 成绩ID
     * @return 成绩
     */
    ServerResult<Results> selectResultsById(Long id);

    /**
     * 查询成绩列表
     * 
     * @param results 成绩
     * @return 成绩集合
     */
    ServerResult<List<Results>> selectResultsList(Results results);

    /**
     * 新增成绩
     * 
     * @param results 成绩
     * @return 结果
     */
    ServerResult<Integer> insertResults(Results results);

    /**
     * 修改成绩
     * 
     * @param results 成绩
     * @return 结果
     */
    ServerResult<Integer> updateResults(Results results);

    /**
     * 批量删除成绩
     * 
     * @param ids 需要删除的成绩ID
     * @return 结果
     */
    ServerResult<Integer> deleteResultsByIds(Long[] ids);

    /**
     * 删除成绩信息
     * 
     * @param id 成绩ID
     * @return 结果
     */
    ServerResult<Integer> deleteResultsById(Long id);
}
